==> php54-owncloud-8.0.3.tgz: share/owncloud/apps/files_sharing/l10n/en_GB.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Server to server sharing is not enabled on this server",
    "The mountpoint name contains invalid characters." : "The mountpoint name contains invalid characters.",
    "Invalid or untrusted SSL certificate" : "Invalid or untrusted SSL certificate",
    "Could not authenticate to remote share, password might be wrong" : "Could not authenticate to remote share, password might be wrong",
    "Storage not valid" : "Storage not valid",
    "Couldn't add remote share" : "Couldn't add remote share",
    "Shared with you" : "Shared with you",
    "Shared with others" : "Shared with others",
    "Shared by link" : "Shared by link",
    "Nothing shared with you yet" : "Nothing shared with you yet",
    "Files and folders others share with you will show up here" : "Files and folders others share with you will show up here",
    "Nothing shared yet" : "Nothing shared yet",
    "Files and folders you share will show up here" : "Files and folders you share will show up here",
    "No shared links" : "No shared links",
    "Files and folders you share by link will show up here" : "Files and folders you share by link will show up here",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Do you want to add the remote share {name} from {owner}@{remote}?",
    "Remote share" : "Remote share",
    "Remote share password" : "Remote share password",
    "Cancel" : "Cancel",
    "Add remote share" : "Add remote share",
    "No ownCloud installation (7 or higher) found at {remote}" : "No ownCloud installation (7 or higher) found at {remote}",
    "Invalid ownCloud url" : "Invalid ownCloud URL",
    "Share" : "Share",
    "Shared by" : "Shared by",
    "A file or folder was shared from <strong>another server</strong>" : "A file or folder was shared from <strong>another server</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "A public shared file or folder was <strong>downloaded</strong>",
    "You received a new remote share from %s" : "You received a new remote share from %s",
    "%1$s accepted remote share %2$s" : "%1$s accepted remote share %2$s",
    "%1$s declined remote share %2$s" : "%1$s declined remote share %2$s",
    "%1$s unshared %2$s from you" : "%1$s unshared %2$s from you",
    "Public shared folder %1$s was downloaded" : "Public shared folder %1$s was downloaded",
    "Public shared file %1$s was downloaded" : "Public shared file %1$s was downloaded",
    "This share is password-protected" : "This share is password-protected",
    "The password is wrong. Try again." : "The password is wrong. Try again.",
    "Password" : "Password",
    "No entries found in this folder" : "No entries found in this folder",
    "Name" : "Name",
    "Share time" : "Share time",
    "Sorry, this link doesn’t seem to work anymore." : "Sorry, this link doesn’t seem to work anymore.",
    "Reasons might be:" : "Reasons might be:",
    "the item was removed" : "the item was removed",
    "the link expired" : "the link expired",
    "sharing is disabled" : "sharing is disabled",
    "For more info, please ask the person who sent this link." : "For more info, please ask the person who sent this link.",
    "Add to your ownCloud" : "Add to your ownCloud",
    "Download" : "Download",
    "Download %s" : "Download %s",
    "Direct link" : "Direct link",
    "Federated Cloud Sharing" : "Federated Cloud Sharing",
    "Allow users on this server to send shares to other servers" : "Allow users on this server to send shares to other servers",
    "Allow users on this server to receive shares from other servers" : "Allow users on this server to receive shares from other servers"
},
"nplurals=2; plural=(n != 1);");

==> php54-owncloud-8.1.0.tgz: share/owncloud/apps/files_sharing/l10n/en_GB.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Server to server sharing is not enabled on this server",
    "The mountpoint name contains invalid characters." : "The mountpoint name contains invalid characters.",
    "Invalid or untrusted SSL certificate" : "Invalid or untrusted SSL certificate",
    "Could not authenticate to remote share, password might be wrong" : "Could not authenticate to remote share, password might be wrong",
    "Storage not valid" : "Storage not valid",
    "Couldn't add remote share" : "Couldn't add remote share",
    "Shared with you" : "Shared with you",
    "Shared with others" : "Shared with others",
    "Shared by link" : "Shared by link",
    "Nothing shared with you yet" : "Nothing shared with you yet",
    "Files and folders others share with you will show up here" : "Files and folders others share with you will show up here",
    "Nothing shared yet" : "Nothing shared yet",
    "Files and folders you share will show up here" : "Files and folders you share will show up here",
    "No shared links" : "No shared links",
    "Files and folders you share by link will show up here" : "Files and folders you share by link will show up here",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Do you want to add the remote share {name} from {owner}@{remote}?",
    "Remote share" : "Remote share",
    "Remote share password" : "Remote share password",
    "Cancel" : "Cancel",
    "Add remote share" : "Add remote share",
    "You can upload into this folder" : "You can upload into this folder",
    "No ownCloud installation (7 or higher) found at {remote}" : "No ownCloud installation (7 or higher) found at {remote}",
    "Invalid ownCloud url" : "Invalid ownCloud URL",
    "Share" : "Share",
    "Shared by" : "Shared by",
    "A file or folder has been <strong>shared</strong>" : "A file or folder has been <strong>shared</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "A file or folder was shared from <strong>another server</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "A public shared file or folder was <strong>downloaded</strong>",
    "You received a new remote share from %s" : "You received a new remote share from %s",
    "%1$s accepted remote share %2$s" : "%1$s accepted remote share %2$s",
    "%1$s declined remote share %2$s" : "%1$s declined remote share %2$s",
    "%1$s unshared %2$s from you" : "%1$s unshared %2$s from you",
    "Public shared folder %1$s was downloaded" : "Public shared folder %1$s was downloaded",
    "Public shared file %1$s was downloaded" : "Public shared file %1$s was downloaded",
    "You shared %1$s with %2$s" : "You shared %1$s with %2$s",
    "You shared %1$s with group %2$s" : "You shared %1$s with group %2$s",
    "%2$s shared %1$s with you" : "%2$s shared %1$s with you",
    "You shared %1$s via link" : "You shared %1$s via link",
    "Shares" : "Shares",
    "This share is password-protected" : "This share is password-protected",
    "The password is wrong. Try again." : "The password is wrong. Try again.",
    "Password" : "Password",
    "No entries found in this folder" : "No entries found in this folder",
    "Name" : "Name",
    "Share time" : "Share time",
    "Sorry, this link doesn’t seem to work anymore." : "Sorry, this link doesn’t seem to work anymore.",
    "Reasons might be:" : "Reasons might be:",
    "the item was removed" : "the item was removed",
    "the link expired" : "the link expired",
    "sharing is disabled" : "sharing is disabled",
    "For more info, please ask the person who sent this link." : "For more info, please ask the person who sent this link.",
    "Add to your ownCloud" : "Add to your ownCloud",
    "Download" : "Download",
    "Download %s" : "Download %s",
    "Direct link" : "Direct link",
    "Federated Cloud Sharing" : "Federated Cloud Sharing",
    "Open documentation" : "Open documentation",
    "Allow users on this server to send shares to other servers" : "Allow users on this server to send shares to other servers",
    "Allow users on this server to receive shares from other servers" : "Allow users on this server to receive shares from other servers",
    "Federated Cloud" : "Federated Cloud"
},
"nplurals=2; plural=(n != 1);");
